==> nativescript-2.0.1.tgz: package/lib/common/mobile/application-manager-base.js <==
"use strict";
var __extends = (this && this.__extends) || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
};
var events_1 = require("events");
var helpers_1 = require("../helpers");
var ApplicationManagerBase = (function (_super) {
    __extends(ApplicationManagerBase, _super);
    function ApplicationManagerBase() {
        _super.apply(this, arguments);
        this.isChecking = false;
    }
    ApplicationManagerBase.prototype.reinstallApplication = function (appIdentifier, packageFilePath) {
        var _this = this;
        return (function () {
            _this.uninstallApplication(appIdentifier).wait();
            _this.installApplication(packageFilePath).wait();
        }).future()();
    };
    ApplicationManagerBase.prototype.restartApplication = function (appIdentifier, bundleExecutable) {
        var _this = this;
        return (function () {
            _this.stopApplication(bundleExecutable || appIdentifier).wait();
            _this.startApplication(appIdentifier).wait();
        }).future()();
    };
    ApplicationManagerBase.prototype.isApplicationInstalled = function (appIdentifier) {
        var _this = this;
        return (function () {
            var installedApplications = _this.getInstalledApplications().wait();
            return _.contains(installedApplications, appIdentifier);
        }).future()();
    };
    ApplicationManagerBase.prototype.checkForApplicationUpdates = function () {
        var _this = this;
        return (function () {
            if (!_this.isChecking) {
                try {
                    _this.isChecking = true;
                    var currentlyInstalledAppIdentifiers = _this.getInstalledApplications().wait();
                    var previouslyInstalledAppIdentifiers = _this.lastInstalledAppIdentifiers || [];
                    var newAppIdentifiers = _.difference(currentlyInstalledAppIdentifiers, previouslyInstalledAppIdentifiers);
                    var removedAppIdentifiers = _.difference(previouslyInstalledAppIdentifiers, currentlyInstalledAppIdentifiers);
                    if (newAppIdentifiers.length || removedAppIdentifiers.length) {
                        _this.applicationsLiveSyncStatus = _.reject(_this.applicationsLiveSyncStatus, function (app) { return _.contains(removedAppIdentifiers, app.applicationIdentifier); });
                        _this.getApplicationsLiveSyncSupportedStatus(newAppIdentifiers).wait();
                    }
                    _.each(newAppIdentifiers, function (application) { return _this.emit("applicationInstalled", application, { isLiveSyncSupported: _this.isLiveSyncSupported(application).wait() }); });
                    _.each(removedAppIdentifiers, function (application) { return _this.emit("applicationUninstalled", application); });
                    _this.lastInstalledAppIdentifiers = currentlyInstalledAppIdentifiers;
                }
                finally {
                    _this.isChecking = false;
                }
            }
        }).future()();
    };
    ApplicationManagerBase.prototype.getApplicationsLiveSyncSupportedStatus = function (newAppIdentifiers) {
        var _this = this;
        return (function () {
            var liveSyncStatus = helpers_1.getFuturesResults(_.map(newAppIdentifiers, function (appIdentifier) { return _this.isLiveSyncSupportedOnDevice(appIdentifier); }), function () { return true; });
            _this.applicationsLiveSyncStatus = (_this.applicationsLiveSyncStatus || [])
                .concat(_.map(newAppIdentifiers, function (appIdentifier, index) {
                return ({ applicationIdentifier: appIdentifier, isLiveSyncSupported: liveSyncStatus[index] });
            }));
        }).future()();
    };
    ApplicationManagerBase.prototype.isLiveSyncSupported = function (appIdentifier) {
        var _this = this;
        return (function () {
            if (!_this.applicationsLiveSyncStatus || !_this.applicationsLiveSyncStatus.length) {
                _this.checkForApplicationUpdates().wait();
            }
            var applicationLiveSyncData = _.find(_this.applicationsLiveSyncStatus, function (app) { return app.applicationIdentifier === appIdentifier; });
            return !!applicationLiveSyncData && !!applicationLiveSyncData.isLiveSyncSupported;
        }).future()();
    };
    ApplicationManagerBase.prototype.isLiveSyncSupportedOnDevice = function (appIdentifier) {
        return (function () {
            throw new Error("This method should not be called.");
        }).future()();
    };
    return ApplicationManagerBase;
})(events_1.EventEmitter);
exports.ApplicationManagerBase = ApplicationManagerBase;

==> nativescript-2.1.0.tgz: package/lib/common/mobile/application-manager-base.js <==
"use strict";
var __extends = (this && this.__extends) || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
};
var events_1 = require("events");
var ApplicationManagerBase = (function (_super) {
    __extends(ApplicationManagerBase, _super);
    function ApplicationManagerBase($logger) {
        _super.call(this);
        this.$logger = $logger;
        this.isChecking = false;
    }
    ApplicationManagerBase.prototype.reinstallApplication = function (appIdentifier, packageFilePath) {
        var _this = this;
        return (function () {
            _this.uninstallApplication(appIdentifier).wait();
            _this.installApplication(packageFilePath).wait();
        }).future()();
    };
    ApplicationManagerBase.prototype.restartApplication = function (appIdentifier, bundleExecutable, framework) {
        var _this = this;
        return (function () {
            _this.stopApplication(bundleExecutable || appIdentifier).wait();
            _this.startApplication(appIdentifier, framework).wait();
        }).future()();
    };
    ApplicationManagerBase.prototype.isApplicationInstalled = function (appIdentifier) {
        var _this = this;
        return (function () {
            if (!_this.lastInstalledAppIdentifiers || !_this.lastInstalledAppIdentifiers.length) {
                _this.checkForApplicationUpdates().wait();
            }
            return _.contains(_this.lastInstalledAppIdentifiers, appIdentifier);
        }).future()();
    };
    ApplicationManagerBase.prototype.checkForApplicationUpdates = function () {
        var _this = this;
        return (function () {
            if (!_this.isChecking) {
                try {
                    _this.isChecking = true;
                    var currentlyInstalledAppIdentifiers = _this.getInstalledApplications().wait();
                    var previouslyInstalledAppIdentifiers = _this.lastInstalledAppIdentifiers || [];
                    var newAppIdentifiers = _.difference(currentlyInstalledAppIdentifiers, previouslyInstalledAppIdentifiers);
                    var removedAppIdentifiers = _.difference(previouslyInstalledAppIdentifiers, currentlyInstalledAppIdentifiers);
                    _this.lastInstalledAppIdentifiers = currentlyInstalledAppIdentifiers;
                    _.each(newAppIdentifiers, function (appIdentifier) { return _this.emit("applicationInstalled", appIdentifier); });
                    _.each(removedAppIdentifiers, function (appIdentifier) { return _this.emit("applicationUninstalled", appIdentifier); });
                }
                finally {
                    _this.isChecking = false;
                }
            }
        }).future()();
    };
    ApplicationManagerBase.prototype.tryStartApplication = function (appIdentifier, framework) {
        var _this = this;
        return (function () {
            try {
                if (_this.isApplicationInstalled(appIdentifier).wait() && _this.canStartApplication()) {
                    _this.startApplication(appIdentifier, framework).wait();
                }
            }
            catch (err) {
                _this.$logger.trace("Unable to start application " + appIdentifier + ". Error is: " + err.message);
            }
        }).future()();
    };
    return ApplicationManagerBase;
}(events_1.EventEmitter));
exports.ApplicationManagerBase = ApplicationManagerBase;
